@@ -1,7 +1,7 @@
 package Data::Sah::Compiler::perl;
 
-our $DATE = '2015-07-08'; # DATE
-our $VERSION = '0.69'; # VERSION
+our $DATE = '2015-09-09'; # DATE
+our $VERSION = '0.70'; # VERSION
 
 use 5.010;
 use strict;
@@ -363,7 +363,7 @@ Data::Sah::Compiler::perl - Compile Sah schema to Perl code
 
 =head1 VERSION
 
-This document describes version 0.69 of Data::Sah::Compiler::perl (from Perl distribution Data-Sah), released on 2015-07-08.
+This document describes version 0.70 of Data::Sah::Compiler::perl (from Perl distribution Data-Sah), released on 2015-09-09.
 
 =head1 SYNOPSIS
 
@@ -472,7 +472,7 @@ C<no> statements, e.g. like below, currently you can generate them manually:
 
 =head2 $c->add_no($cd, $module)
 
-This is the counterpart of C<add_use()>, to generate C<<no foo>> statement.
+This is the counterpart of C<add_use()>, to generate C<no foo> statement.
 
 See also: C<add_use()>.
 
