@@ -1,7 +1,7 @@
 package Data::Sah::Compiler::perl::TH::cistr;
 
-our $DATE = '2015-07-08'; # DATE
-our $VERSION = '0.69'; # VERSION
+our $DATE = '2015-09-09'; # DATE
+our $VERSION = '0.70'; # VERSION
 
 use 5.010;
 use strict;
@@ -149,7 +149,7 @@ Data::Sah::Compiler::perl::TH::cistr - perl's type handler for type "cistr"
 
 =head1 VERSION
 
-This document describes version 0.69 of Data::Sah::Compiler::perl::TH::cistr (from Perl distribution Data-Sah), released on 2015-07-08.
+This document describes version 0.70 of Data::Sah::Compiler::perl::TH::cistr (from Perl distribution Data-Sah), released on 2015-09-09.
 
 =for Pod::Coverage ^(clause_.+|superclause_.+|handle_.+|before_.+|after_.+)$
 
@@ -159,9 +159,9 @@ Should probably be reimplemented using special Perl string type, or special Perl
 operators, instead of simulated using C<lc()> on a per-clause basis. The
 implementation as it is now is not "contagious", e.g. C<< [cistr =>
 check_each_elem => '$_ eq "A"'] >> should be true even if data is C<"Aaa">,
-since one would expect C<<$_ eq "A">> is also done case-insensitively, but it is
-currently internally implemented by converting data to lowercase and splitting
-per character to become C<<["a", "a", "a"]>>.
+since one would expect C<< $_ eq "A" >> is also done case-insensitively, but it
+is currently internally implemented by converting data to lowercase and
+splitting per character to become C<< ["a", "a", "a"] >>.
 
 Or, avoid C<cistr> altogether and use C<prefilters> to convert to
 lowercase/uppercase first before processing.
